aboutsummaryrefslogtreecommitdiff
path: root/src/graph/view3D/main3d.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/graph/view3D/main3d.c')
-rw-r--r--src/graph/view3D/main3d.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/graph/view3D/main3d.c b/src/graph/view3D/main3d.c
index a3d2e3a0..313e9040 100644
--- a/src/graph/view3D/main3d.c
+++ b/src/graph/view3D/main3d.c
@@ -102,12 +102,12 @@ int mono, totalColors, totalSolid, totalDithered, totalHues,
int drawMore;
-int spadMode=no, /* yes if receiving AXIOM command and
+int spadMode=no, /* yes if receiving OpenAxiom command and
calling drawViewport */
spadDraw=no; /* yes if drawing viewport for
- an AXIOM command */
+ an OpenAxiom command */
int spadSignalReceived=0; /* yes if current state is a result of
- a signal from AXIOM */
+ a signal from OpenAxiom */
int inNextEvent=no; /* true just before a call to
XNextEvent */
jmp_buf jumpFlag;
@@ -181,7 +181,7 @@ int finishedList=no, zoomed=yes, translated = yes,
gotToggle = no;
poly *quickList;
- /** if not connected to AXIOM **/
+ /** if not connected to OpenAxiom **/
int viewAloned;
/** for drawing the box **/
@@ -273,7 +273,7 @@ main(void)
/**** link Xwindows to viewports - X10 feature ****/
table = XCreateAssocTable(nbuckets);
/**** Create AXIOM color map ****/
totalShades = 0;
totalColors = XInitSpadFill(dsply,scrn,&colorMap,
&totalHues,&totalSolidShades,
@@ -520,7 +520,7 @@ main(void)
i = 123; /* Used in viewman, what is this for? */
code = check(write(Socket,&i,intSize));
/* Check if I am getting stuff from AXIOM or, if I am viewAlone. */
readViewman(&viewAloned,intSize);
readViewman(&viewData,sizeof(view3DStruct));
readViewman(&i,intSize);
@@ -541,7 +541,7 @@ main(void)
switch (viewData.typeOf3D) {
/* Currently, the view3DType information doesn't get sent from
- AXIOM - all surfaces are alike regardless of how they
+ OpenAxiom - all surfaces are alike regardless of how they
were created. We may revert back to receiving this information
in case we want to take advantage of certain properties of
certain surfaces (e.g. z=f(x,y)). */
@@ -273,7 +273,7 @@ main(void)
/**** link Xwindows to viewports - X10 feature ****/
table = XCreateAssocTable(nbuckets);
- /**** Create AXIOM color map ****/
+ /**** Create OpenAxiom color map ****/
totalShades = 0;
totalColors = XInitSpadFill(dsply,scrn,&colorMap,
@@ -520,7 +520,7 @@ main(void)
i = 123; /* Used in viewman, what is this for? */
code = check(write(Socket,&i,intSize));
- /* Check if I am getting stuff from AXIOM or, if I am viewAlone. */
+ /* Check if I am getting stuff from OpenAxiom or, if I am viewAlone. */
readViewman(&viewAloned,intSize);
readViewman(&viewData,sizeof(view3DStruct));